==> qtjambi-remoteobjects-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiRemoteObjects/QRemoteObjectReplica_shell.h <==
#ifndef QREMOTEOBJECTREPLICA_SHELL_H
#define QREMOTEOBJECTREPLICA_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtRemoteObjects/qremoteobjectpendingcall.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectReplica_shell : public QRemoteObjectReplica, public QtJambiShellInterface
{
public:
    QRemoteObjectReplica_shell(qint32 t0 = QRemoteObjectReplica::DefaultConstructor);
    ~QRemoteObjectReplica_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initialize() override;
    void setNode(QRemoteObjectNode* node0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectReplica_access : public QRemoteObjectReplica
{
    void __qt_initializeNode_QRemoteObjectNode_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID node0, jstring name1);
    void __qt_persistProperties_cref_QString_cref_QByteArray_cref_QList_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1, jobject props2) const;
    jobject __qt_propAsVariant_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint i0) const;
    jobject __qt_retrieveProperties_cref_QString_cref_QByteArray_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1) const;
    void __qt_send_QMetaObject_Call_int_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint call0, jint index1, jobject args2);
    jobject __qt_sendWithReply_QMetaObject_Call_int_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint call0, jint index1, jobject args2);
    void __qt_setChild_int_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint i0, jobject arg__2);
    void __qt_setProperties_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject arg__1);
    void __qt_initialize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setNode_QRemoteObjectNode_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID node0);
    static inline const std::type_info& __registerEnumTypeInfo_ConstructorType() {
        return RegistryAPI::registerEnumTypeInfo<QRemoteObjectReplica::ConstructorType>("QRemoteObjectReplica::ConstructorType", "io/qt/remoteobjects/QRemoteObjectReplica$ConstructorType");
    }
};

#endif // QREMOTEOBJECTREPLICA_SHELL_H

==> qtjambi-remoteobjects-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiRemoteObjects/QRemoteObjectReplica_shell.h <==
#ifndef QREMOTEOBJECTREPLICA_SHELL_H
#define QREMOTEOBJECTREPLICA_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtRemoteObjects/qremoteobjectpendingcall.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectReplica_shell : public QRemoteObjectReplica, public QtJambiShellInterface
{
public:
    QRemoteObjectReplica_shell(qint32 t0 = QRemoteObjectReplica::DefaultConstructor);
    ~QRemoteObjectReplica_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initialize() override;
    void setNode(QRemoteObjectNode* node0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectReplica_access : public QRemoteObjectReplica
{
    void __qt_initializeNode_QRemoteObjectNode_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID node0, jstring name1);
    void __qt_persistProperties_cref_QString_cref_QByteArray_cref_QList_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1, jobject props2) const;
    jobject __qt_propAsVariant_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint i0) const;
    jobject __qt_retrieveProperties_cref_QString_cref_QByteArray_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1) const;
    void __qt_send_QMetaObject_Call_int_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint call0, jint index1, jobject args2);
    jobject __qt_sendWithReply_QMetaObject_Call_int_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint call0, jint index1, jobject args2);
    void __qt_setChild_int_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint i0, jobject arg__2);
    void __qt_setProperties_rval_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject arg__1);
    void __qt_initialize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setNode_QRemoteObjectNode_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID node0);
    static inline const std::type_info& __registerEnumTypeInfo_ConstructorType() {
        return RegistryAPI::registerEnumTypeInfo<QRemoteObjectReplica::ConstructorType>("QRemoteObjectReplica::ConstructorType", "io/qt/remoteobjects/QRemoteObjectReplica$ConstructorType");
    }
};

#endif // QREMOTEOBJECTREPLICA_SHELL_H
